# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/sec-downloader',
                'doc_host': 'https://Elijas.github.io',
                'git_url': 'https://github.com/Elijas/sec-downloader',
                'lib_path': 'sec_downloader'},
  'syms': { 'sec_downloader.core': { 'sec_downloader.core.DownloadStorage': ('core.html#downloadstorage', 'sec_downloader/core.py'),
                                     'sec_downloader.core.DownloadStorage.__enter__': ( 'core.html#downloadstorage.__enter__',
                                                                                        'sec_downloader/core.py'),
                                     'sec_downloader.core.DownloadStorage.__exit__': ( 'core.html#downloadstorage.__exit__',
                                                                                       'sec_downloader/core.py'),
                                     'sec_downloader.core.DownloadStorage.__init__': ( 'core.html#downloadstorage.__init__',
                                                                                       'sec_downloader/core.py'),
                                     'sec_downloader.core.DownloadStorage._read_files': ( 'core.html#downloadstorage._read_files',
                                                                                          'sec_downloader/core.py'),
                                     'sec_downloader.core.DownloadStorage.get_file_contents': ( 'core.html#downloadstorage.get_file_contents',
                                                                                                'sec_downloader/core.py')}}}
